@@ -10,6 +10,7 @@
 #include <libnotify/notify.h>
 
 #include <locale.h>
+#include <langinfo.h>
 
 #include "update-notifier.h"
 #include "hooks.h"
@@ -206,7 +207,15 @@ char *hook_file_lookup_i18n(struct rfc822_header *rfc822, char *field)
 	 return s;
    }
 
-   /* try $field-$languagecode_$countrycode first */
+   /* try $field-$languagecode_$countrycode.$codeset first */
+   s = g_strdup_printf("%s-%s.%s", field, get_lang_code(FALSE), nl_langinfo(CODESET));
+   entry = rfc822_header_lookup(rfc822, s);
+   //g_debug("Looking for: %s ; found: %s\n",s,entry);
+   g_free(s);
+   if(entry != NULL)
+      return entry;
+
+   /* try $field-$languagecode_$countrycode (and assume utf-8) */
    s = g_strdup_printf("%s-%s", field, get_lang_code(FALSE));
    entry = rfc822_header_lookup(rfc822, s);
    //g_debug("Looking for: %s ; found: %s\n",s,entry);
@@ -214,7 +223,15 @@ char *hook_file_lookup_i18n(struct rfc822_header *rfc822, char *field)
    if(entry != NULL)
       return entry;
 
-   /* try $field-$languagecode next */
+   /* try $field-$languagecode.$codeset next */
+   s = g_strdup_printf("%s-%s.%s", field, get_lang_code(TRUE), nl_langinfo(CODESET));
+   //g_debug("Looking for: %s ; found: %s\n",s,entry);
+   entry = rfc822_header_lookup(rfc822, s);
+   g_free(s);
+   if(entry != NULL)
+      return entry;
+
+   /* try $field-$languagecode (and assume utf-8 codeset) */
    s = g_strdup_printf("%s-%s", field, get_lang_code(TRUE));
    //g_debug("Looking for: %s ; found: %s\n",s,entry);
    entry = rfc822_header_lookup(rfc822, s);
@@ -309,14 +326,27 @@ gboolean show_next_hook(TrayApplet *ta, GList *hooks)
    }
    char *summary = hook_description_get_summary(rfc822);
    char *descr = hook_description_get_description(rfc822);
-   char *s = g_strdup_printf("%s\n\n%s\n",gettext(summary), gettext(descr));
-   gtk_text_buffer_set_text(buf, s, -1);
+   char *s;
+   if(summary) {
+      s = g_strdup_printf("%s\n\n%s\n",gettext(summary), gettext(descr));
+      gtk_text_buffer_set_text(buf, s, -1);
+      // set the name to bold
+      GtkTextIter start, end;
+      gtk_text_buffer_get_iter_at_offset(buf, &start, 0);
+      gtk_text_buffer_get_iter_at_offset(buf, &end, g_utf8_strlen(gettext(summary),-1));
+      gtk_text_buffer_apply_tag_by_name(buf, "bold_tag", &start, &end);
 
-   // set the name to bold
-   GtkTextIter start, end;
-   gtk_text_buffer_get_iter_at_offset(buf, &start, 0);
-   gtk_text_buffer_get_iter_at_offset(buf, &end, g_utf8_strlen(gettext(summary),-1));
-   gtk_text_buffer_apply_tag_by_name(buf, "bold_tag", &start, &end);
+   } else {
+      s = g_strdup_printf("%s\n",gettext(descr));
+      gtk_text_buffer_set_text(buf, s, -1);
+   }
+
+   // set button name (if needed)
+   char *b = hook_file_lookup_i18n(rfc822, "ButtonText");
+   if(b)
+      gtk_button_set_label(GTK_BUTTON (button_run), b);
+   else
+      gtk_button_set_label(GTK_BUTTON (button_run), _("_Run this action now"));
 
    // clean up
    fclose(f);
@@ -391,6 +421,7 @@ void show_hooks(TrayApplet *ta)
 
    GladeXML *xml = priv->glade_xml;
    GtkWidget *dia = glade_xml_get_widget(xml, "dialog_hooks");
+   //gtk_window_set_title(GTK_WINDOW(dia), _("Information available"));
    assert(dia);
    GtkWidget *button_run = glade_xml_get_widget(xml, "button_run");
    assert(button_run);
@@ -448,8 +479,16 @@ gboolean is_hook_relevant(const gchar *hook_file)
    }
    struct rfc822_header *rfc822 = rfc822_parse_stanza(f);
 
+   // check if its a note that is relevant only for admin users
+   // (this is the default)
+   gchar *b = rfc822_header_lookup(rfc822, "OnlyAdminUsers");
+   if(b == NULL || g_ascii_strncasecmp(b, "true",-1) == 0) {
+      if (!in_admin_group())
+	 return FALSE;
+   }
+
    // check the DontShowAfterReboot flag
-   gchar *b = rfc822_header_lookup(rfc822, "DontShowAfterReboot");
+   b = rfc822_header_lookup(rfc822, "DontShowAfterReboot");
    if(b != NULL && g_ascii_strncasecmp(b, "true",-1) == 0) {
       g_debug("found DontShowAfterReboot");
 
@@ -497,6 +536,9 @@ static gboolean show_notification(void *data)
    TrayApplet *ta = (TrayApplet*)data;
    HookTrayAppletPrivate *priv = (HookTrayAppletPrivate*)ta->user_data;
 
+   if(!gtk_status_icon_get_visible(ta->tray_icon))
+      return FALSE;
+
    GtkWidget *d = glade_xml_get_widget(priv->glade_xml,"dialog_hooks");
    if((d && GTK_WIDGET_VISIBLE(d)) || priv->active_notification != NULL)
       return FALSE;
