@@ -37,9 +37,9 @@ show_notification (TrayApplet *ta)
 	n = notify_notification_new_with_status_icon(
 				     _("System restart required"),
 				     _("To complete the update of your system, "
-				       "restart your system.\n\n"
-				       "Click on the notification icon to "
-				       "restart your system."),
+				       "please restart it.\n\n"
+				       "Click on the notification icon for "
+				       "details."),
 				     GTK_STOCK_DIALOG_WARNING,
 				     ta->tray_icon);
 	notify_notification_set_timeout (n, 60000);
@@ -106,8 +106,8 @@ request_reboot (void)
 	gnome_client_request_save (client,
 				   GNOME_SAVE_GLOBAL,
 				   TRUE,
-				   GNOME_INTERACT_NONE,
-				   FALSE,
+				   GNOME_INTERACT_ANY,
+				   TRUE,
 				   TRUE);
 }
 
