@@ -185,7 +185,7 @@ gboolean file_monitor_periodic_check(gpointer data)
    UpgradeNotifier *un = (UpgradeNotifier *)data;
 
    // we are not ready yet, wait for the next timeslice
-   if((un->update == NULL) || (un->reboot == NULL) || (un->crashreport == NULL))
+   if((un->reboot == NULL) || (un->crashreport == NULL))
       return TRUE;
 
    // DPkg::Post-Invoke has written a stamp file, that means a install/remove
@@ -329,8 +329,12 @@ tray_icons_init(UpgradeNotifier *un)
    /* new upates tray icon */
    un->update = g_new0 (TrayApplet, 1);
 
-   trayapplet_create(un->update, "software-update-available");
-   update_tray_icon_init(un->update);
+   // check if the updates icon should be displayed
+   if (in_admin_group()) {
+      trayapplet_create(un->update, "software-update-available");
+      update_tray_icon_init(un->update);
+   } else 
+      un->update = NULL;
 
    /* update hook icon*/
    un->hook = g_new0 (TrayApplet, 1);
@@ -350,6 +354,18 @@ tray_icons_init(UpgradeNotifier *un)
    return FALSE; // for the tray_destroyed_cb
 }
 
+gboolean
+system_user()
+{
+   /* do not start for system users, e.g. the guest session 
+    * (see /usr/share/gdm/guest-session/guest-session-setup.sh)
+    */
+   uid_t uid = getuid();
+   if (uid < 500)
+      return TRUE;
+   return FALSE;
+}
+
 // this function checks if the user is in the admin group
 // if there is no admin group, we return true becuase there
 // is no way to figure if the user is a admin or not
@@ -418,14 +434,13 @@ main (int argc, char *argv[])
 	gtk_window_set_default_icon_name ("update-notifier");
 
 	//g_print("starting update-notifier\n");
-	
-	// check if we should run at all (see HideAdminTools spec
-	// on https://wiki.ubuntu.com/HideAdminToolsToUsers)
-	if(!in_admin_group() && !FORCE_START) {
-	   g_warning("not starting because user is not in admin group\n");
+
+	// do not run as system user (e.g. guest user)
+	if (system_user()) {
+	   g_warning("not starting for system user\n");
 	   exit(0);
 	}
-
+	
 	client = gnome_master_client ();
 	if (up_get_clipboard ())
 	  gnome_client_set_restart_style (client, GNOME_RESTART_ANYWAY);
